# discovery_imaging_utils
Imaging utilities for the Discovery Program at the University of Minnesota. Utilities assist with the analysis of resting-state fMRI data (primarily through fMRIPREP), along with other miscellaneous utilities for FreeSurfer and general imaging analysis.

This package is undergoing active development and should be used with caution.

The package can be installed through "pip install discovery-imaging-utils", and required dependancies can be installed by going to the requirements.txt file and running "pip install -r requirements.txt"
